aboutsummaryrefslogtreecommitdiffstats
path: root/Demos/Device/ClassDriver/MIDI/MIDI.c
diff options
context:
space:
mode:
authorDean Camera <dean@fourwalledcubicle.com>2009-08-05 06:36:31 +0000
committerDean Camera <dean@fourwalledcubicle.com>2009-08-05 06:36:31 +0000
commitc5038f1bf44aea75f1ae1ed035cb7d523ccfdacb (patch)
tree5cf62e8642cc53c49eb28f973db843df5f047ba3 /Demos/Device/ClassDriver/MIDI/MIDI.c
parent357ccc577bc6f8710ff942019e16cfa6a08466b7 (diff)
downloadlufa-c5038f1bf44aea75f1ae1ed035cb7d523ccfdacb.tar.gz
lufa-c5038f1bf44aea75f1ae1ed035cb7d523ccfdacb.tar.bz2
lufa-c5038f1bf44aea75f1ae1ed035cb7d523ccfdacb.zip
Renamed all library events to properly seperate out Device and Host mode events. Changed the firing conditions for some events to ensure that events are fired by their own USB mode only.
Remove VBUS events - not needed as the library takes care of VBUS detection and feedback on supported AVRs via the USB_Device_Connected and USB_Device_Disconnected events. Fixed incorrect Host state assignment in the incomplete BluetoothHost demo.
Diffstat (limited to 'Demos/Device/ClassDriver/MIDI/MIDI.c')
-rw-r--r--Demos/Device/ClassDriver/MIDI/MIDI.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/Demos/Device/ClassDriver/MIDI/MIDI.c b/Demos/Device/ClassDriver/MIDI/MIDI.c
index fcb86d661..f1a0d9afc 100644
--- a/Demos/Device/ClassDriver/MIDI/MIDI.c
+++ b/Demos/Device/ClassDriver/MIDI/MIDI.c
@@ -157,19 +157,19 @@ void CheckJoystickMovement(void)
}
/** Event handler for the library USB Connection event. */
-void EVENT_USB_Connect(void)
+void EVENT_USB_Device_Connect(void)
{
LEDs_SetAllLEDs(LEDMASK_USB_ENUMERATING);
}
/** Event handler for the library USB Disconnection event. */
-void EVENT_USB_Disconnect(void)
+void EVENT_USB_Device_Disconnect(void)
{
LEDs_SetAllLEDs(LEDMASK_USB_NOTREADY);
}
/** Event handler for the library USB Configuration Changed event. */
-void EVENT_USB_ConfigurationChanged(void)
+void EVENT_USB_Device_ConfigurationChanged(void)
{
LEDs_SetAllLEDs(LEDMASK_USB_READY);
@@ -177,8 +177,8 @@ void EVENT_USB_ConfigurationChanged(void)
LEDs_SetAllLEDs(LEDMASK_USB_ERROR);
}
-/** Event handler for the library USB Unhandled Control Packet event. */
-void EVENT_USB_UnhandledControlPacket(void)
+/** Event handler for the library USB Unhandled Control Request event. */
+void EVENT_USB_Device_UnhandledControlRequest(void)
{
- MIDI_Device_ProcessControlPacket(&Keyboard_MIDI_Interface);
+ MIDI_Device_ProcessControlRequest(&Keyboard_MIDI_Interface);
}